/***************************************************************************
 *   Copyright (C) 2008 by Daniel Calviño Sánchez                          *
 *   danxuliu@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/

#include <kaction.h>
#include <kactioncollection.h>
#include <klocalizedstring.h>

#include "KTutorial.h"
#include "view/TutorialManagerDialog.h"

using view::TutorialManagerDialog;

//public:

class TutorialKXmlGuiClient: public KXMLGUIClient {
public:
    TutorialKXmlGuiClient(KXMLGUIClient* parent): KXMLGUIClient(parent) {
        setComponentData(KComponentData("ktutorial"));
        setXMLFile("ktutorialui.rc");
    }
};

void KTutorial::setup(KXmlGuiWindow* window) {
    TutorialKXmlGuiClient* tutorialClient= new TutorialKXmlGuiClient(window);

    mTutorialsAction = new KAction(window);
    mTutorialsAction->setText(i18nc("@action:inmenu", "Tutorials..."));
    tutorialClient->actionCollection()->addAction("tutorials", mTutorialsAction);
    connect(mTutorialsAction, SIGNAL(triggered(bool)),
            this, SLOT(showTutorialManagerDialog()));

    connect(mTutorialmanager, SIGNAL(started(const QString&)),
            this, SLOT(disableTutorialsAction()));
    connect(mTutorialmanager, SIGNAL(finished()),
            this, SLOT(enableTutorialsAction()));

    mParent = window;
}

void KTutorial::showTutorialManagerDialog() const {
    QDialog* dialog = new TutorialManagerDialog(mTutorialmanager, mParent);
    dialog->setAttribute(Qt::WA_DeleteOnClose);
    dialog->setModal(true);

    dialog->show();
}

//private:

KTutorial* KTutorial::sSelf = new KTutorial();

void KTutorial::disableTutorialsAction() {
    mTutorialsAction->setEnabled(false);
}

void KTutorial::enableTutorialsAction() {
    mTutorialsAction->setEnabled(true);
}
