/***************************************************************************
 *   Copyright (C) 2008 by Daniel Calviño Sánchez                          *
 *   danxuliu@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/

#include <kdebug.h>

#include "Tutorial.h"
#include "KTutorial.h"
#include "Step.h"
#include "TutorialInformation.h"

#include "view/StepWidget.h"

using view::StepWidget;

//public:

void Tutorial::addStep(Step* step) {
    if (mSteps.contains(step->id())) {
        kWarning() << "Step with id " << step->id() << " already added in tutorial "
                   << mTutorialInformation->id();
        return;
    }

    step->setParent(this);

    mSteps.insert(step->id(), step);
}

void Tutorial::start() {
    if (!mSteps.contains("start")) {
        kError() << "No start step found in tutorial " << mTutorialInformation->id();
        emit finished();
        return;
    }

    StepWidget* stepWidget = new StepWidget(tutorialInformation()->name(),
                                            KTutorial::self()->parentWidget());
    connect(this, SIGNAL(stepActivated(Step*)),
            stepWidget, SLOT(setStep(Step*)));
    connect(stepWidget, SIGNAL(finished()), this, SIGNAL(finished()));

    setup();

    nextStep("start");
}

void Tutorial::nextStep(const QString& id) {
    if (!mSteps.contains(id)) {
        kError() << "No step " << id << " found in tutorial " << mTutorialInformation->id();
        return;
    }

    nextStep(mSteps.value(id));
}

void Tutorial::nextStep(Step* step) {
    if (mSteps.key(step).isEmpty()) {
        kWarning() << "Activate step " << step->id() << " which doesn't belong to tutorial "
                   << mTutorialInformation->id();
    }

    if (mCurrentStep != 0) {
        mCurrentStep->setActive(false);
    }

    //TODO remove
    kDebug() << "Next step: " << step->id() << endl;

    emit stepActivated(step);

    mCurrentStep = step;
    mCurrentStep->setActive(true);
}
