/***************************************************************************
 *   Copyright (C) 2008 by Daniel Calviño Sánchez                          *
 *   danxuliu@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/

#include "TutorialManagerDialog.h"
#include "TutorialListModel.h"
#include "../TutorialInformation.h"
#include "../TutorialManager.h"

namespace view {

//public:

TutorialManagerDialog::TutorialManagerDialog(TutorialManager* tutorialManager,
                                             QWidget* parent):
        KDialog(parent),
    mTutorialManager(tutorialManager) {

    QWidget *widget = new QWidget(this);
    ui.setupUi(widget);

    setMainWidget(widget);

    setCaption(i18nc("@title:window", "Tutorial manager"));
    setButtons(KDialog::User1 | KDialog::Close);

    ui.tutorialsList->setModel(new TutorialListModel(tutorialManager, this));

    setButtonIcon(User1, KIcon("dialog-ok"));
    setButtonText(User1, i18nc("@action:button", "Start"));
    setButtonToolTip(User1, i18nc("@info:tooltip", "Start the selected tutorial"));
    setButtonWhatsThis(User1, i18nc("@info:whatsthis", "Start the selected tutorial"));
    enableButton(User1, false);

    //TODO Select index when the list is navigated with keyboard arrows?
    connect(ui.tutorialsList, SIGNAL(activated(const QModelIndex&)),
            this, SLOT(select(const QModelIndex&)));
    connect(this, SIGNAL(user1Clicked()), this, SLOT(start()));

    connect(mTutorialManager, SIGNAL(finished()), this, SLOT(finish()));
}

//public slots:

void TutorialManagerDialog::finish() {
    show();
}

//private:

void TutorialManagerDialog::select(const TutorialInformation* tutorialInformation) {
    if (tutorialInformation == 0) {
        return;
    }

    enableButton(User1, true);

    ui.descriptionLabel->setText(tutorialInformation->description());

    mCurrentTutorialInformation = tutorialInformation;
}

//private slots:

void TutorialManagerDialog::select(const QModelIndex& index) {
    const TutorialListModel* model = qobject_cast<const TutorialListModel*>(index.model());

    select(model->getTutorialInformationForIndex(index));
}

void TutorialManagerDialog::start() {
    hide();

    mTutorialManager->start(mCurrentTutorialInformation->id());
}

}
